@@ -48,6 +48,8 @@ class upconfig(object):
         :return:
         """
         try:
+            with open(self.updatePath, encoding="utf-8-sig") as f:
+                self.config.read_file(f)
             self.config.set(self.update_tag, f'{name}', date)
         except configparser.NoSectionError:
             with open(self.updatePath, 'a') as f:
@@ -70,6 +72,8 @@ class upconfig(object):
             value = self.config.get(self.update_tag, f'{name}')
         except:
             try:
+                with open(self.updatePath, encoding="utf-8-sig") as f:
+                    self.config.read_file(f)
                 self.config.set(self.update_tag, f'{name}', getdate(1))  # 如果报错说明没有这个则需要创建一个，并赋值为前一日
             except configparser.NoSectionError:
                 with open(self.updatePath, 'a') as f:
